@@ -2,6 +2,18 @@
 The registry module provides tools to maintain a registry of channels and
 static file dependencies.
 
+The first thing that should happen when django starts is registration of
+channels. It should happen first, because channels are required for
+autocomplete widgets. And autocomplete widgets are required for forms. And
+forms are required for ModelAdmin.
+
+It looks like this:
+
+- in ``yourapp/autocomplete_light_registry.py``, register your channels with
+  ``autocomplete_light.register()``,
+- in ``urls.py``, do ``autocomplete_light.autodiscover()`` **before**
+  ``admin.autodiscover()``.
+
 ChannelRegistry
     Subclass of Python's dict type with registration/unregistration methods.
 
@@ -56,10 +68,10 @@ class ChannelRegistry(dict):
             if len(self._static[path]) == 0:
                 del self.static_list[self.static_list.index(path)]
 
-    def register(self, *args):
-        """ Proxy registry.register_model_channel() or
-        registry.register_channel() if there is no apparent model for the
-        channel.
+    def register(self, *args, **kwargs):
+        """
+        Proxy registry.register_model_channel() or registry.register_channel()
+        if there is no apparent model for the channel.
 
         Example usages::
 
@@ -73,6 +85,17 @@ class ChannelRegistry(dict):
             # Register a channel without model, ensure that SomeChannel.model
             # is None (which is the default):
             autocomplete_light.register(SomeChannel)
+
+            # As of 0.5, you may also pass attributes*, ie.:
+            autocomplete_light.register(SomeModel, search_field='search_names',
+                result_template='somemodel_result.html')
+
+        You may pass attributes via kwargs, only if the registry creates a
+        type:
+
+        - if no channel class is passed,
+        - or if the channel class has no model attribute,
+        - and if the channel classs is not generic
         """
 
         channel = None
@@ -88,11 +111,11 @@ class ChannelRegistry(dict):
             model = channel.model
 
         if model:
-            self.register_model_channel(model, channel)
+            self.register_model_channel(model, channel, **kwargs)
         else:
             self.register_channel(channel)
 
-    def register_model_channel(self, model, channel=None):
+    def register_model_channel(self, model, channel=None, **kwargs):
         """
         Add a model to the registry, optionnaly with a given channel class.
 
@@ -103,6 +126,10 @@ class ChannelRegistry(dict):
             The channel class to register the model with, default to
             ChannelBase.
 
+        kwargs
+            Extra attributes to set to the channel class, if created by this
+            method.
+
         Three cases are possible:
 
         - specify model class and ModelNameChannel will be generated extending
@@ -115,12 +142,14 @@ class ChannelRegistry(dict):
 
         To keep things simple, the name of a channel is it's class name.
         """
+        kwargs.update({'model': model})
+
         if channel is None:
             channel = type('%sChannel' % model.__name__, (ChannelBase,),
-                {'model': model})
+                kwargs)
         elif channel.model is None:
             channel = type('%sChannel' % model.__name__, (channel,),
-                {'model': model})
+                kwargs)
 
         self.register_channel(channel)
         self._models[channel.model] = channel
@@ -224,6 +253,6 @@ def autodiscover():
     _autodiscover(registry)
 
 
-def register(*args):
+def register(*args, **kwargs):
     """Proxy registry.register"""
-    return registry.register(*args)
+    return registry.register(*args, **kwargs)
