@@ -23,16 +23,18 @@ def autocomplete_light_static(include_autocomplete=True, include_deck=True,
     if include_style:
         static_list.append('autocomplete_light/style.css')
 
-    static_list += autocomplete_light.static_list
+    static_list += autocomplete_light.registry.static_list
 
     output = ''
     for file in static_list:
         if file[-3:] == '.js':
-            output += '<script src="%s%s" type="text/javascript"></script>' % (
-                settings.STATIC_URL, file)
+            output += '''
+                <script src="%s%s" type="text/javascript"></script>
+                '''.strip() % (settings.STATIC_URL, file)
         elif file[-4:] == '.css':
-            output += '<link rel="stylesheet" type="text/css" href="%s%s" />' % (
-                settings.STATIC_URL, file)
+            output += '''
+                <link rel="stylesheet" type="text/css" href="%s%s"/>
+                '''.strip() % (settings.STATIC_URL, file)
 
     return output
 
@@ -41,14 +43,3 @@ def autocomplete_light_static(include_autocomplete=True, include_deck=True,
 def autocomplete_light_result_as_html(result, channel):
     """Return channel.result_as_html for result and channel."""
     return channel.result_as_html(result)
-
-
-@register.filter
-def autocomplete_light_result_as_json(result, channel):
-    """
-    Return channel.result_as_json for result and channel.
-
-    Note that result_as_json is defined in JsonChannelBase, **not**
-    ChannelBase.
-    """
-    return channel.result_as_json(result)
